@@ -7,6 +7,7 @@ class AutocompleteModel(object):
     limit_choices = 20
     choices = None
     search_fields = None
+    split_words = False
 
     def choice_value(self, choice):
         return choice.pk
@@ -29,7 +30,7 @@ class AutocompleteModel(object):
         assert self.choices is not None, 'choices should be a queryset'
         assert self.search_fields, 'autocomplete.search_fields must be set'
         q = self.request.GET.get('q', '')
-        exclude = self.request.GET.getlist('exclude', [])
+        exclude = self.request.GET.getlist('exclude')
 
         # Apply keyword searches.
         def construct_search(field_name):
@@ -41,7 +42,15 @@ class AutocompleteModel(object):
                 return "%s__icontains" % field_name
 
         conditions = Q()
-        if q:
+
+        if self.split_words:
+            for word in q.strip().split():
+                word_conditions = Q()
+                for search_field in self.search_fields:
+                    word_conditions |= Q(**{construct_search(search_field):
+                        word})
+                conditions &= word_conditions
+        else:
             for search_field in self.search_fields:
                 conditions |= Q(**{construct_search(search_field): q})
 
